Change Log for v0.4.x — OppiaMobile 0.7.1 documentation

# Change Log for v0.4.x

## v0.4.4 - released: 18-Aug-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/179 - Filter courses by tag
- Fix https://github.com/DigitalCampus/django-oppia/issues/178 - Visualisations to cover last year only
- Fix https://github.com/DigitalCampus/django-oppia/issues/180 - Visualisations - allow selection of start date
- Fix https://github.com/DigitalCampus/django-oppia/issues/96 - Course activity - allow selection of start/end dates
- Fix https://github.com/DigitalCampus/django-oppia/issues/147 - Update docs for Virtual Machine
- Fix https://github.com/DigitalCampus/django-oppia/issues/183 - Graph loading image
- Fix https://github.com/DigitalCampus/django-oppia/issues/182 - Allow selection of date range and interval on graphs

## v0.4.3 - released: 18-Jul-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/175 - Error in signals.py

## v0.4.2 - released: 2-Jul-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/174 - Error in course API call

## v0.4.1 - released: 27-May-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/150 - add optional job title and organisation to profile
- Reset password facility https://github.com/DigitalCampus/django-oppia/issues/168
- Fix https://github.com/DigitalCampus/django-oppia/issues/173
- Fix https://github.com/DigitalCampus/django-oppia/issues/171

## v0.4.0 - released: 1-Apr-2014

- Moved to using BootStrap for design
- https://github.com/DigitalCampus/django-oppia/issues/119 - using gravatars now optional